// Demo 8: Squares.java
//
//       A Squares Demo
//   Simple Java Squares Class
//
//   A Squares object includes an array of Squares
//
//       by Charles W. Neville
//   Copyright Charles W. Neville, June 1999
//
//  Continuing A. Square's great tradition of "Flatland",  
//  Here is A Squares Demo, which includes almost as
//  many Squares as A. Square wrote about himself.
//
//  Class Squares is designed to be used by other classes.
//
//  A Squares object is intended to be a group of Square objects,
//  or, more simply stated, a group of squares, which can move as a unit.
//
//  A Squares object should know
//    1. How to report how many Square objects in contains (get method).
//    2. How to return any one of its constituent Square objects
//         (get method).
//    4. How to set the size of each of its constituent Square objects
//         to a given common value (set method).
//    5. How to set the color of each of its constituent Square objects
//         to a given common Color (set method).
//    6. How to move its Square objects into a default configuration (a
//         vertical column of squares).
//    7. How to expand the size of each of its constituent Square objects
//         by a given amount (method).
//    8. How to move each of its constituent Square objects as a group 
//         (method).
//    9. How to draw itself (methods).

//  Note: Same as the CS 151 Demo of the same name.

import java.awt.*;
import Square;

public class Squares {

   private Square[] squareArray;  // the array of Squares

   // A Squares constructor: Constructs a Squares object arranged as a
   // vertical column of squares in a given color.  The parameters are:
     //  int x;        // common x coordinate of the
     //                // Squares in the array
     //  int y;        // y coordinate of top Square
     //  int size;     // common size of the Squares
     //  Color color;  // common Color of the Squares
     //  int yincr;    // y increment between successive Squares 
     //  int n;        // the number of Squares in the array
   public Squares(int x, int y, int size,
                  Color color, int yincr, int n) {

     int newy;

     // create the array
     squareArray = new Square[n];

     // initialize the array
     newy = y;
     for(int i = 0; i < n; i++) {
        squareArray[i] = new Square(x, newy, size, color);
        newy = newy + yincr;
     }

   } // Squares constructor

   // return number of Squares we contain
   public int getNumber() {

      return squareArray.length;

   } // getNumber()

   // return the ith square
   public Square getSquare(int i) {

      return squareArray[i];

   } // getSquare()

   // set the size of our Squares to a common value
   public void setSize(int size) {

      for(int i = 0; i < squareArray.length; i++) {

         squareArray[i].setSize(size);

      }

   } // setSize()

   // set the color of our Squares to a common value
   public void setColor(Color color) {

      for(int i = 0; i < squareArray.length; i++) {

         squareArray[i].setColor(color);

      }

   } // setColor()

   // move our Squares into the default vertical column configuration
      // parameters: int x -- the common x coordinate of our Squares
      //                      in pixels
      //             int y -- the y coordinate of our top Square, in
      //                      pixels
      //             int yincr -- the vertical spacing between the tops
      //                          of our Squares, in pixels
   public void moveToColumn(int x, int y, int yincr) {

      int newy = y;

      for(int i = 0; i < squareArray.length; i++) {

         squareArray[i].setX(x);
         squareArray[i].setY(newy);
         newy = newy + yincr;

      }

   } // moveToColumn()

   // expand the size of our Squares by s pixels
   public void expand(int s) {

      for(int i = 0; i < squareArray.length; i++) {

        squareArray[i].expand(s);

      }

   } // expand()

   // move our Squares r pixels to right and s pixels down
   public void move(int r, int s) {

       // increment x coord of each square in array
      for(int i = 0; i < squareArray.length; i++) {

        squareArray[i].move(r, s);
      }

   } // move()

   // draw each Square in its natural color
   public void draw(Graphics g) {

     for(int i = 0; i < squareArray.length; i++) {
        squareArray[i].draw(g);
     }

   } // draw(Graphics g)

   // draw each Square in the given color
   public void draw(Graphics g, Color color) {

      for(int i = 0; i < squareArray.length; i++) {
        squareArray[i].draw(g, color);
      }

   } // draw(Graphics g, Color color)

} // class Squares
 
      

     
     
